package cmdVM

import (
    u "nexus-client/utils"
    g "nexus-client/globals"
)

type Del struct {
    Name string
}

func (cmd *Del)GetName() string {
    return cmd.Name
}

func (cmd *Del)GetDesc() []string {
    return []string{
        "Deletes one or more VMs.",
        "If not the VM's owner: requires VM_DESTROY VM access capability or VM_DESTROY_ANY user capability."}
}

func (cmd *Del)PrintUsage() {
    printRegexUsage(cmd)
    printRegexUsageDetails()
}

func (cmd *Del)Run(args []string) int {
    client := g.GetInstance().Client
    host := g.GetInstance().Host

    argc := len(args)
    if argc < 1 {
        cmd.PrintUsage()
        return 1
    }

    vms, err := getFilteredVMs("/vms/del", args)
    if err != nil {
        u.PrintlnErr(err.Error())
        return 1
    }

    if len(vms) == 0 {
        u.PrintlnErr("Error: VM(s) not found.")
        return 1
    }

    statusCode := 0

    for _, vm := range(vms) {
        uuid := vm.ID.String()
        resp, err := client.R().Delete(host+"/vms/"+uuid)
        if err != nil {
            u.PrintlnErr("Failed deleting VM \""+vm.Name+"\": "+err.Error())
            statusCode = 1
        } else {
            if resp.IsSuccess() {
                u.Println("Deleted VM \""+vm.Name+"\"")
            } else {
                u.PrintlnErr("Failed deleting VM \""+vm.Name+"\": "+resp.Status()+": "+resp.String())
                statusCode = 1
            }
        }

    }

    return statusCode
}
