package template

import (
    "time"
    "encoding/json"
    "github.com/google/uuid"
)

// Template fields to be serialized over the network.
type (
    TemplateSerialized struct {
        ID     uuid.UUID       `json:"id"           validate:"required"`
        Name   string          `json:"name"         validate:"required,min=2,max=256"`
        Owner  string          `json:"owner"        validate:"required,email"`
        Access string          `json:"access"       validate:"required,min=4,max=16"` // private or public
        CreationTime time.Time `json:"creationTime" validate:"required"`
    }
)

// Converts a TemplateSerialized structure into a pretty string.
func (t *TemplateSerialized)String() (string, error) {
    output, err := json.MarshalIndent(t, "", "    ")
    if err != nil {
        return "", err
    }
    return string(output), nil
}
